import { hasGlobalPrivacyControlConsent } from '../../src/utils/globalPrivacyControl';

declare global {
  interface Navigator {
    globalPrivacyControl: string | undefined;
  }
}

describe('hasGlobalPrivacyControlConsent', () => {
  it('returns `true` if no signal provided', () => {
    expect(hasGlobalPrivacyControlConsent()).toBe(true);
  });

  it.each`
    gpcValue         | hasConsent
    ${'1'}           | ${false}
    ${'0'}           | ${true}
    ${'unspecified'} | ${true}
    ${undefined}     | ${true}
  `(
    'returns `$hasConsent` if navigator.globalPrivacyControl is `$gpcValue`',
    ({ hasConsent, gpcValue }) => {
      Object.defineProperty(navigator, 'globalPrivacyControl', {
        writable: true,
        value: gpcValue,
      });
      expect(hasGlobalPrivacyControlConsent()).toBe(hasConsent);
      navigator.globalPrivacyControl = undefined;
    }
  );
});
